@@ -1,6 +1,7 @@
 #include <cpp11/doubles.hpp>
 #include <cpp11/matrix.hpp>
 #include <deque>
+#include "Rinternals.h"
 #include "vector.h"
 #include "quadTree.h"
 
@@ -9,11 +10,10 @@ cpp11::writable::doubles_matrix<> collision_c(cpp11::doubles_matrix<> pos,
                                               cpp11::doubles_matrix<> vel,
                                               cpp11::doubles radii,
                                               double strength) {
-  size_t i;
   cpp11::writable::doubles_matrix<> res(pos.nrow(), pos.ncol());
   QuadTree<2> tree;
   std::deque<Body<2> *> bodies;
-  for (i = 0; i < pos.nrow(); ++i) {
+  for (R_xlen_t i = 0; i < pos.nrow(); ++i) {
     Body<2> * body = new Body<2>();
     body->pos.coord[0] = pos(i, 0);
     body->pos.coord[1] = pos(i, 1);
@@ -26,10 +26,10 @@ cpp11::writable::doubles_matrix<> collision_c(cpp11::doubles_matrix<> pos,
 
   tree.insertBodies(bodies);
 
-  for (i = 0; i < pos.nrow(); ++i) {
+  for (R_xlen_t i = 0; i < pos.nrow(); ++i) {
     tree.collideBodies(bodies[i]);
   }
-  for (i = 0; i < pos.nrow(); ++i) {
+  for (R_xlen_t i = 0; i < pos.nrow(); ++i) {
     res(i, 0) = bodies[i]->force.coord[0];
     res(i, 1) = bodies[i]->force.coord[1];
   }
